@extends('layouts.pmar.theme')
@section("title", env("APP_NAME") . " :: SEI!")
@section('content')
    <section>
        <div class="container">
            <div class="row">
                <hr/>
                <div class="col-12">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb">
                            <li class="breadcrumb-item">
                                <a href="{{ route("paginas.home") }}">Portal</a>
                            </li>
                            <li class="breadcrumb-item active" aria-current="page">Portal SEI Angra</li>
                        </ol>
                    </nav>
                </div>



                {{-- <div class="col-12">
                    <h1>Portal SEI Angra</h1>
                </div> --}}
                {{-- <nav class="navbar navbar-expand-lg navbar-light fixed-top shadow-sm" id="mainNav">
                    <div class="container px-5">
                        <a class="navbar-brand fw-bold" href="#page-top"><img id="logo-nav" src="assets/img/logo-sei-angra.png"
                                alt="Sei Angra dos Reis"></a>
                        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarResponsive"
                            aria-controls="navbarResponsive" aria-expanded="false" aria-label="Toggle navigation">
                            Menu
                            <i class="bi-list"></i>
                        </button>
                        <div class="collapse navbar-collapse" id="navbarResponsive">
                            <ul class="navbar-nav ms-auto my-3 my-lg-0">
                                <li class="nav-item"><a class="nav-link me-lg-3" href="#capacitacao">Capacitação</a></li>
                                <li class="nav-item"><a class="nav-link me-lg-3" href="#cadastrarse">Cadastro</a></li>
                                <li class="nav-item"><a class="nav-link me-lg-3" href="#perguntas">Perguntas frequentes</a></li>
                                <li class="nav-item"><a class="nav-link me-lg-3" href="#legislacao">Legislação</a></li>
                                <li class="nav-item"><a class="nav-link me-lg-3" href="#suporte">Suporte</a></li>
                            </ul>
                            <div class="dropdown">
                                <a class="btn btn-primary dropdown-toggle me-lg-3" href="#" role="button" id="dropdownMenuLink"
                                    data-bs-toggle="dropdown" aria-expanded="false">
                                    <i class="fa-solid fa-door-open p-2"></i> Acessar Sei
                                </a>
                                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                                    <li><a class="dropdown-item" target="_blank" href="http://angra.sei.rj.gov.br">Usuário
                                            Interno</a></li>
                                    <li><a class="dropdown-item" type="button" class="btn btn-primary" data-bs-toggle="modal"
                                            data-bs-target="#staticBackdrop">Usuário
                                            Externo</a></li>
                                </ul>
                            </div>
                            <a href="https://angra.sei.rj.gov.br/consultaprocessual" target="_blank"
                                class="btn btn-success me-lg-3"><i class="fa-solid fa-search p-2"></i> Consultar processos</a>
                        </div>
                    </div>
                </nav> --}}


                <!-- Modal -->
                <div class="modal fade" id="staticBackdrop" data-bs-backdrop="static" data-bs-keyboard="false" tabindex="-1"
                    aria-labelledby="staticBackdropLabel" aria-hidden="true">
                    <div class="modal-dialog">
                        <div class="modal-content">
                            <div class="modal-header text-center">
                                <h1 class="modal-title fs-3 fw-bolder" id="staticBackdropLabel">Antes de acessar, leia os treinamentos
                                    rápidos:</h1>
                                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                            </div>
                            <div class="modal-body">
                                <div class="row d-flex justify-content-center text-center">
                                    <div class="col p-3 d-flex justify-content-center">
                                        <div class="card" style="width: 18rem;">
                                            <div class="card-body">
                                                <h5 class="card-title">1 - Iniciando Processo como usuário Externo</h5>
                                                <a href="assets/1-COMO-ABRIR-PROCESSO-COMO-USUARIO-EXTERNO.pdf" target="_blank" class="fw-bolder btn btn-success col-12">Aprender</a>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="col p-3 d-flex justify-content-center">
                                        <div class="card" style="width: 18rem;">
                                            <div class="card-body">
                                                <h5 class="card-title">2 - Como anexar documentação em um processo já existente <br>
                                                    <p class="fs-6 fw-bold pt-2">(Peticionamento Intercorrente)</p></h5>
                                                <a href="assets/2-COMO-ANEXAR-DOCUMENTACAO-EM-PROCESSO-EXISTENTE.pdf" target="_blank" class="fw-bolder btn btn-success col-12">Aprender</a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="modal-footer text-center d-flex justify-content-center">
                                <button onclick="window.open('https://angra.sei.rj.gov.br/externo', '_blank');" type="button"
                                    class="btn btn-primary fs-4 m-3 text-center shadow border-0 fw-bolder">ACESSAR - Já SEI! <br> Certifico que já possuo o conhecimento necessário.</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Banner Emergencial -->
                <!-- <aside class="text-center bg-dark mt-5">
                    <div class="container px-5">
                        <div class="row gx-5 justify-content-center">
                            <div class="col-xl-12">
                                <div class="h2 fs-1 text-white mb-4">
                                    <span class="shadow-text">Manutenção SEI-RJ<br>
                                        <small>
                                            Informamos que o SEI-RJ passará por manutenção amanhã, 31/07/2024 a partir das 20:00.
                                            NÃO há previsão de indisponibilidade.
                                            Esta manutenção é necessária para que possam ser realizadas ações visando a otimização
                                            do funcionamento do sistema.
                                        </small>
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                </aside> -->

                <!-- Mashead header-->
                <header class="masthead">
                    <div class="container px-5">
                        <div class="row gx-5 align-items-center">
                            <div class="col-lg-6">
                                <!-- Mashead text and app badges-->
                                <div class="mb-5 mb-lg-0 text-center text-lg-start">
                                    <h1 class="display-1 lh-1 mb-3">Sistema Eletrônico de Informações</h1>
                                    <p class="lead fw-normal text-muted mb-5">A gestão de documentos e processos da Prefeitura de
                                        Angra dos Reis, agora é 100% digital.</p>
                                </div>
                            </div>
                            <div class="col-lg-6">
                                <!-- Masthead device mockup feature-->
                                <div class="masthead-device-mockup">
                                    <svg class="circle" viewBox="0 0 100 100" xmlns="http://www.w3.org/2000/svg">
                                        <defs>
                                            <linearGradient id="circleGradient" gradientTransform="rotate(45)">
                                                <stop class="gradient-start-color" offset="0%"></stop>
                                                <stop class="gradient-end-color" offset="100%"></stop>
                                            </linearGradient>
                                        </defs>
                                        <circle cx="50" cy="50" r="50"></circle>
                                    </svg>
                                    <img class="img-fluid" src="assets/img/note.png" alt="" style="position: absolute; z-index: 1;">
                                </div>
                            </div>
                        </div>
                    </div>
                </header>

                <!-- Basic features section-->
                <section id="consulta" class="bg-gradient-primary-to-secondary">
                    <div class="container px-5">
                        <div class="row justify-content-center align-items-center g-2">
                            <div class="col-sm-5 col-md-4 mb-3 mx-5">
                                <div class="px-5 px-sm-0"><img class="img-fluid rounded-circle" src="assets/img/repetition.jpg"
                                        alt="Ilustração de alguém verificando documentos." />
                                </div>
                            </div>
                            <div class="col p-2">
                                <h3 class="shadow-text fs-2 my-3">Pesquisa Pública</h3>
                                <p class="fs-5">
                                    <a href="https://angra.sei.rj.gov.br/consultaprocessual" target="_blank"
                                        class="bg-white fw-bolder p-2 rounded-5">Clique aqui</a> para fazer <strong>consultas
                                        processuais</strong> inerentes ao SEI-ANGRA.
                                </p>
                                <br>
                                <h3 class="shadow-text fs-2 my-3">Validação de Documentos</h3>
                                <p class="fs-5">

                                    <a href="https://angra.sei.rj.gov.br/validardocumento" target="_blank"
                                        class="bg-white fw-bolder p-2 rounded-5">Clique aqui</a> para <strong>validar
                                        documentos</strong> do SEI-ANGRA. Desta forma você confirma a veracidade do documento
                                    desejado.
                                </p>

                            </div>
                            <!-- <div class="col-12 p-2">

                                </div> -->
                        </div>
                </section>
                <!-- Call to action section-->


                <!-- App features section-->
                <section id="features">
                    <div class="container px-5">
                        <div class="row container-fluid align-items-center">
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-person-check icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Menos burocracia</h3>
                                    <p class="text-muted mb-0">Facilidade para abertura e consulta de processos</p>
                                </div>
                            </div>
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-search icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Transparência</h3>
                                    <p class="text-muted mb-0">Velocidade no acesso à informações</p>
                                </div>
                            </div>
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-laptop icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Praticidade</h3>
                                    <p class="text-muted mb-0">Consulta ao sistema via internet</p>
                                </div>
                            </div>
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-stopwatch icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Velocidade</h3>
                                    <p class="text-muted mb-0">Mais agilidade, eficiência e celeridade aos processos</p>
                                </div>
                            </div>
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-currency-dollar icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Economia e Sustentabilidade</h3>
                                    <p class="text-muted mb-0">Economia de papel e material de escritório</p>
                                </div>
                            </div>
                            <div class="col-md-4 mb-5">
                                <!-- Feature item-->
                                <div class="text-center">
                                    <i class="bi-folder-check icon-feature text-gradient d-block mb-3"></i>
                                    <h3 class="font-alt">Integração</h3>
                                    <p class="text-muted mb-0">Comunicação interna 100% digital entre os setores públicos</p>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>


                <!-- Quote/testimonial aside-->
                <aside class="text-center bg-gradient-primary-to-secondary">
                    <div class="container px-5">
                        <div class="row gx-5 justify-content-center">
                            <div class="col-xl-12">
                                <div class="h2 fs-1 text-white mb-4"><span class="shadow-text">Toda comunicação interna da
                                        Prefeitura de Angra dos Reis será tramitada digitalmente. Esse modelo dará mais agilidade,
                                        transparência, eficiência e celeridade aos processos.</span></div>
                            </div>
                        </div>
                    </div>
                </aside>


                <!-- Basic features section-->
                <section id="capacitacao">
                    <div class="container mb-5">
                        <div class="row">
                            <div class="col-12 p-3 text-center">
                                <h1>Capacitação Sei</h1>
                            </div>
                        </div>
                    </div>
                    <div class="container px-5">
                        <div class="row justify-content-center">
                            <div class="col-xl-3 col-lg-6 col-md-6 col-12 mb-lg-5 d-flex justify-content-center">
                                <div class="card border-0 shadow my-4" style="width: 18rem;">
                                    <img class="card-img-top img-fluid d-block" src="assets/img/lives.jpg"
                                        alt="Treinamento Sei Angra dos Reis">
                                    <div class="card-body px-3">
                                        <h5 class="card-title">Lives de Treinamento SEI Angra dos Reis</h5>
                                        <p class="card-text">Treinamento sobre o SEI Angra, que ocorreu nos dias 08 e 09 de janeiro.
                                        </p>
                                    </div>
                                    <div class="card-footer mb-2"><a href="lives.html" class="btn btn-primary">Assistir</a></div>
                                </div>
                            </div>
                            <div class="col-xl-3 col-lg-6 col-md-6 col-12 mb-lg-5 d-flex justify-content-center">
                                <div class="card border-0 shadow my-4" style="width: 18rem;">
                                    <img class="card-img-top img-fluid d-block" src="assets/img/SEI-USAR.jpg" alt="Curso Livre Sei">
                                    <div class="card-body px-3">
                                        <h5 class="card-title">Curso Livre - SEI! USAR (ENAP)</h5>
                                        <p class="card-text">Curso online gratuito, oferecido pela Escola Nacional de Administração
                                            Pública (ENAP).</p>
                                    </div>
                                    <div class="card-footer mb-2"><a href="https://www.escolavirtual.gov.br/curso/74"
                                            target="_blank" class="btn btn-primary">Fazer Curso</a></div>
                                </div>
                            </div>
                            <div class="col-xl-3 col-lg-6 col-md-6 col-12 mb-lg-5 d-flex justify-content-center">
                                <div class="card border-0 shadow my-4" style="width: 18rem;">
                                    <img class="card-img-top img-fluid d-block" src="assets/img/wiki.jpg" alt="Wiki Sei RJ">
                                    <div class="card-body px-3">
                                        <h5 class="card-title">Wiki SEI-RJ</h5>
                                        <p class="card-text">Todas as informações sobre o funcionamento do sistema, como manuais,
                                            FAQs e procedimentos operacionais (POP's).</p>
                                    </div>
                                    <div class="card-footer mb-2"><a href="https://wikisei.rj.gov.br/P%C3%A1gina_principal"
                                            class="btn btn-primary">Acessar</a></div>
                                </div>
                            </div>
                            <div class="col-xl-3 col-lg-6 col-md-6 col-12 mb-lg-5 d-flex justify-content-center">
                                <div class="card border-0 shadow my-4" style="width: 18rem;">
                                    <img class="card-img-top img-fluid d-block" src="assets/img/sei-pernambuco.jpg"
                                        alt="Treinamento Sei de Pernambuco">
                                    <div class="card-body px-3">
                                        <h5 class="card-title">Playlist de Conhecimento</h5>
                                        <p class="card-text">Treinamento em vídeos sobre o SEI, oferecido pelo estado de Pernambuco.
                                        </p>
                                    </div>
                                    <div class="card-footer mb-2"><a href="lives-treinamento-pernambuco.html" target="_blank"
                                            class="btn btn-primary">Assistir</a></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>


                <aside id="cadastrarse" class="text-center bg-gradient-secondary-to-primary mt-5">
                    <div class="container px-5">
                        <div class="row gx-5 justify-content-center">
                            <div class="col-xl-12">
                                <div class="h2 fs-1 text-white mb-4">

                                    <span class="shadow-text my-3">Quero me cadastrar no SEI!<br> <br></span>

                                    <a data-bs-toggle="tooltip" data-bs-placement="bottom"
                                        title="Servidores e Empresas Locadas na PMAR"
                                        class="btn fs-5 btn-outline-light py-3 px-4 rounded-pill"
                                        href="https://portaldoservidor.angra.rj.gov.br/sistema-sei.asp" target="_blank"><i
                                            class="fa-solid fa-landmark p-2"></i>Cadastro Interno</a>

                                    <a data-bs-toggle="tooltip" data-bs-placement="bottom" title="Munícipes de Angra dos Reis"
                                        class="btn fs-5 btn-outline-light py-3 px-4 rounded-pill"
                                        href="https://angra.sei.rj.gov.br/sei/controlador_externo.php?acao=usuario_externo_enviar_cadastro&id_orgao_acesso_externo=0"
                                        target="_blank"><i class="fa-solid fa-globe p-2"></i>Cadastro Externo</a>

                                </div>
                            </div>
                        </div>
                    </div>
                </aside>


                <!-- Basic features section-->
                <section class="bg-light" id="perguntas">
                    <div class="container mb-5">
                        <div class="row">
                            <div class="col-12 p-3 text-center">
                                <h1>Perguntas Frequentes</h1>
                            </div>
                        </div>
                    </div>

                    <div class="container px-5">
                        <div class="row gx-5">
                            <div class="col-12">
                                <div class="accordion accordion-flush" id="accordionFlushExample">
                                    <h3 class="lead">Sobre o SEI!</h3>
                                    <div id="primeirasPerguntas">
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading00">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse00"
                                                    aria-expanded="false" aria-controls="flush-collapse00">
                                                    O que é o SEI? </button>
                                            </h2>
                                            <div id="flush-collapse00" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading00" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>O Sistema Eletrônico de Informações (SEI) é um sistema de produção e gestão
                                                        de
                                                        documentos e processos eletrônicos desenvolvido pelo Tribunal Regional
                                                        Federal
                                                        da 4ª Região (TRF4) e cedido gratuitamente à administração pública.
                                                    </p>
                                                    <p>
                                                        O SEI foi escolhido como a solução de processo eletrônico no âmbito do
                                                        projeto
                                                        Processo Eletrônico Nacional (PEN) - iniciativa conjunta de órgãos e
                                                        entidades
                                                        de diversas esferas da administração pública, com o intuito de construir uma
                                                        infraestrutura pública de processos e documentos administrativos
                                                        eletrônicos, e
                                                        têm sido implementados em vários órgãos e entidades das mais variadas
                                                        esferas
                                                        administrativas.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading01">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse01"
                                                    aria-expanded="false" aria-controls="flush-collapse01"> Para que serve?
                                                </button>
                                            </h2>
                                            <div id="flush-collapse01" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading01" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p> O SEI possui diversas funcionalidades e permitem estabelecer a gestão de
                                                        documentos de forma sistematizada por meio de:
                                                    <ul>
                                                        <li>Produção de documentos dentro do ambiente do próprio sistema e
                                                            assinatura
                                                            eletrônica;</li>
                                                        <li>Controle do nível de acesso, gerenciamento e o trâmite de processos e
                                                            documentos
                                                            restritos e sigilosos, conferindo o acesso somente às unidades
                                                            envolvidas ou
                                                            a
                                                            usuários específicos;</li>
                                                        <li>Criação de modelos de documentos;</li>
                                                        <li>Criação de textos padrão;</li>
                                                        <li>Criação de Base de Conhecimento dos processos (fluxo de trâmite do
                                                            processo);</li>
                                                        <li>Autuação do documento em qualquer unidade administrativa e tramitação em
                                                            múltiplas unidades, que podem ser demandadas simultaneamente e
                                                            manifestar-se
                                                            no
                                                            mesmo expediente administrativo;</li>
                                                        <li>Acompanhamento especial do andamento dos processos de interesse da
                                                            unidade; </li>
                                                        <li>Controle de prazos; estatísticas da unidade e tempo do trâmite do
                                                            processo; </li>
                                                        <li>Assinatura de documentos por meio de blocos de assinatura;</li>
                                                        <li>Organização interna de processos em bloco;</li>
                                                        <li>Sobrestamento de processos;</li>
                                                        <li>Pesquisa em todo teor, nos casos de processos públicos;</li>
                                                        <li>Inspeção administrativa, com fornecimento de estatísticas da unidade
                                                            (tais
                                                            como:
                                                            tempo de trâmite do processo, quantidade e tipos de documentos gerados);
                                                        </li>
                                                        <li>Acesso externo ao processo (gerencia o acesso de usuários externos aos
                                                            expedientes administrativos que lhes digam respeito, permitindo que
                                                            tomem
                                                            conhecimento do teor do processo e, por exemplo, assinem remotamente
                                                            contratos e
                                                            outros tipos de documentos);</li>
                                                        </li>
                                                        Dentre outras funcionalidades.
                                                        </li>
                                                    </ul>
                                                    <p>O SEI tem ainda vantagens tecnológicas e econômicas importantes para as
                                                        organizações públicas:</p>
                                                    <ul>
                                                        <li>Portabilidade: 100% Web e acessado por meio dos principais navegadores
                                                            do
                                                            mercado: Internet Explorer, Firefox e Google Chrome;</li>
                                                        <li>Acesso Remoto: pode ser acessado remotamente por diversos tipos de
                                                            equipamentos,
                                                            como microcomputadores, notebooks, tablets e smartphones de vários
                                                            sistemas
                                                            operacionais (Windows, Linux, IOS e Android). Isto possibilita que os
                                                            usuários
                                                            trabalhem a distância;</li>
                                                        <li>Sistema intuitivo: estruturado com boa navegabilidade e usabilidade;
                                                        </li>
                                                        <li>Economia nos contratos de compra de papel; em outsourcing, material de
                                                            escritório e serviço de postagem, redução de custos em logística e
                                                            transporte de
                                                            documentos, e permite maior produtividade, rapidez, transparência e
                                                            segurança
                                                            aos trâmites administrativos.</li>
                                                    </ul>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading02">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse02"
                                                    aria-expanded="false" aria-controls="flush-collapse02">
                                                    Como será realizada a implantação do SEI em Angra dos Reis? </button>
                                            </h2>
                                            <div id="flush-collapse02" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading02" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>A implantação do SEI nos órgãos e entidades da PMAR será de forma gradativa e
                                                        escalonada - denominada “ondas”, conforme plano de implantação a ser
                                                        definido
                                                        pela Superintendência de Tecnologia da Informação - SUTIN.</p>
                                                </div>
                                            </div>

                                            <div class="accordion-item">
                                                <h2 class="accordion-header" id="flush-heading03">
                                                    <button class="accordion-button collapsed text-dark" type="button"
                                                        data-bs-toggle="collapse" data-bs-target="#flush-collapse03"
                                                        aria-expanded="false" aria-controls="flush-collapse03">
                                                        Quem são os PONTOS FOCAIS do SEI da Câmara Municipal e da Prefeitura?
                                                    </button>
                                                </h2>

                                                <!-- ACCORDION DOS PONTOS FOCAIS -->
                                                <div id="flush-collapse03" class="accordion-collapse collapse"
                                                    aria-labelledby="flush-heading03" data-bs-parent="#accordionFlushExample">
                                                    <div class="accordion-body">

                                                        <div class="container mt-5">
                                                            <div class="accordion" id="instituicoesAccordion">

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="cgmHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#camaraCollapse" aria-expanded="false"
                                                                            aria-controls="camaraCollapse">
                                                                            Câmara Municipal de Angra dos Reis
                                                                        </button>
                                                                    </h2>
                                                                    <div id="camaraCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="camaraHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Bernard de Oliveira Maia</strong><br>
                                                                                    Matrícula: 5272<br>
                                                                                    Tel: (24) 2404-1713 <br>
                                                                                    Email: sti@angradosreis.rj.leg.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Carlos Frederico de Carvalho
                                                                                    </strong><br>
                                                                                    Matrícula: 4545<br>
                                                                                    Tel: (24) 2404-1713 <br>
                                                                                    Email: sti@angradosreis.rj.leg.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Thiago da Silva Oliveira Souza
                                                                                    </strong><br>
                                                                                    Matrícula: 5270<br>
                                                                                    Tel: (24) 2404-1713 <br>
                                                                                    Email: sti@angradosreis.rj.leg.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Maximiliano Moreira Rodrigues
                                                                                    </strong><br>
                                                                                    Matrícula: 4616<br>
                                                                                    Tel: (24) 2404-1713 <br>
                                                                                    Email: sti@angradosreis.rj.leg.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>5- André da Glória Santos Ferreira
                                                                                    </strong><br>
                                                                                    Matrícula: 8289<br>
                                                                                    Tel: (24) 2404-1713 <br>
                                                                                    Email: sti@angradosreis.rj.leg.br
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="angraprevHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#angraprevCollapse"
                                                                            aria-expanded="false" aria-controls="angraprevCollapse">
                                                                            Instituto de Previdência Social do Município de Angra
                                                                            dos Reis (ANGRAPREV)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="angraprevCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="angraprevHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Camille Gomes Dourado</strong><br>
                                                                                    Matrícula: 2500275<br>
                                                                                    Tel: (24) 3365-5388 <br>
                                                                                    Email: angraprev@angra.rj.gov.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Thiago Lima da Fonseca</strong><br>
                                                                                    Matrícula: 2500264<br>
                                                                                    Tel: (24) 3365-5388 <br>
                                                                                    Email: angraprev@angra.rj.gov.br
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="cgmHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#cgmCollapse"
                                                                            aria-expanded="false" aria-controls="cgmCollapse">
                                                                            Controladoria Geral do Município (CGM)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="cgmCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="cgmHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Magda Neves Angelo</strong><br>
                                                                                    Matrícula: 16972<br>
                                                                                    Ramal: 1166 <br>
                                                                                    Tel: (24) 3365-6131 <br>
                                                                                    Email: cgm.cgab@angra.rj.gov.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Jobson Rodrigues da Silva
                                                                                    </strong><br>
                                                                                    Matrícula: 19706<br>
                                                                                    Ramal: 1172 <br>
                                                                                    Tel: (24) 3377-8302 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Sandro Campos Sales
                                                                                    </strong><br>
                                                                                    Matrícula: 29268<br>
                                                                                    Tel: (24) 3377-8302 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Bernadete Guedes Correia
                                                                                    </strong><br>
                                                                                    Matrícula: 3296<br>
                                                                                    Tel: (24) 3377-8302 <br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="turisangraHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#turisangraCollapse"
                                                                            aria-expanded="false"
                                                                            aria-controls="turisangraCollapse">
                                                                            Fundação de Turismo de Angra dos Reis (TURISANGRA)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="turisangraCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="turisangraHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Christian da Silva
                                                                                        Galois</strong><br>
                                                                                    Matrícula: 190341<br>
                                                                                    Ramal: 7711 <br>
                                                                                    Tel: (24) 3369-7711<br>
                                                                                    Email: tur.citt@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Rodrigo da Silva</strong><br>
                                                                                    Matrícula: 10614<br>
                                                                                    Ramal: 7518 <br>
                                                                                    Tel: (24) 3367-7789 <br>
                                                                                    Email: turisangra@angra.rj.gov
                                                                                </li>
                                                                                <!--
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Rosângela de Oliveira
                                                                                        Lima</strong><br>
                                                                                    Matrícula: 3945<br>
                                                                                    Ramal: 1294 <br>
                                                                                    Tel: (24) 3367-7789 <br>
                                                                                    Email: tur.copes@angra.rj.gov
                                                                                </li>
            -->
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="imaarHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#imaarCollapse" aria-expanded="false"
                                                                            aria-controls="imaarCollapse">
                                                                            Instituto Municipal do Ambiente de Angra dos Reis
                                                                            (IMAAR)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="imaarCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="imaarHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Vinicíos Júdice dos
                                                                                        Santos</strong><br>
                                                                                    Matrícula: 19075<br>
                                                                                    Ramal: 1041 <br>
                                                                                    Tel: (24) 3368-6418 <br>
                                                                                    Email: imaar.dprot@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Bruno Reis de Lima</strong><br>
                                                                                    Matrícula: 19062<br>
                                                                                    Ramal: 6418 <br>
                                                                                    Tel: (24) 3368-6418 <br>
                                                                                    Email: breislim@gmail.com
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="pgmHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#pgmCollapse"
                                                                            aria-expanded="false" aria-controls="pgmCollapse">
                                                                            Procuradoria Geral do Município (PGM)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="pgmCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="pgmHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Irene de Oliveira Mello de
                                                                                        Almeida</strong><br>
                                                                                    Matrícula: 28128<br>
                                                                                    Tel: (24) 3377-8339
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Rafaela Pimenta Serrão</strong><br>
                                                                                    Matrícula: 27153<br>
                                                                                    Tel: (24) 3377-8339
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="saaeHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#saaeCollapse"
                                                                            aria-expanded="false" aria-controls="saaeCollapse">
                                                                            Serviço Autônomo de Captação de Água e Tratamento de
                                                                            Esgoto (SAAE)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="saaeCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="saaeHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Flaviano Chies</strong><br>
                                                                                    Matrícula: 10621<br>
                                                                                    Ramal: 1578 <br>
                                                                                    Email: protocolo@saaeangra.com.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Antônio Carlos Ferreira Soares
                                                                                        Junior</strong><br>
                                                                                    Matrícula: 191107<br>
                                                                                    Ramal: 1577 <br>
                                                                                    Email: antonio.soares@saaeangra.com.br
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sadHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sadCollapse"
                                                                            aria-expanded="false" aria-controls="sadCollapse">
                                                                            Secretaria de Administração (SAD)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sadCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sadHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <span class="py-3">Departamento de Protocolo</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Benedito Paulo Pereira Cascardo</strong><br>
                                                                                    Matrícula: 19740<br>
                                                                                    Ramal: 5396 <br>
                                                                                    Tel: (24) 3365-5396 <br>
                                                                                </li>
                                                                                <span class="py-3">Secretaria de
                                                                                    Administração</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Daniel do Carmo Neves</strong><br>
                                                                                    Matrícula: 3391<br>
                                                                                    Ramal: 1076 <br>
                                                                                    Tel: (24) 3365-7415 <br>
                                                                                    Email: sad.dgnp@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Luciana Fagundes de
                                                                                        Oliveira</strong><br>
                                                                                    Matrícula: 17859<br>
                                                                                    Ramal: 1078 <br>
                                                                                    Tel: (24) 3365-7415 <br>
                                                                                    Email: sad.cogab@angra.rj.gov
                                                                                </li>
                                                                                <span class="py-3">Secretaria-Executiva de Gestão de
                                                                                    Suprimentos</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Vera Lúcia Amaral Felipe</strong><br>
                                                                                    Matrícula: 26729<br>
                                                                                    Ramal: 1156 <br>
                                                                                    Tel: (24) 3365-6439 <br>
                                                                                    Email: atasderegistro@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Willian Barbosa da Costa</strong><br>
                                                                                    Matrícula: 20436<br>
                                                                                    Ramal: 1163 <br>
                                                                                    Tel: (24) 3377-7906 <br>
                                                                                    Email: adpe@angra.rj.gov
                                                                                </li>
                                                                                <span class="py-3">Secretaria-Executiva de Recursos
                                                                                    Humanos</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>5- Carlos Eduardo Borges
                                                                                        Campanário</strong><br>
                                                                                    Matrícula: 18075<br>
                                                                                    Ramal: 1479 <br>
                                                                                    Tel: (24) 3365-5391 <br>
                                                                                    Email: adpe@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>6- Cristiane Viteldo Braz
                                                                                        Waleriano</strong><br>
                                                                                    Matrícula: 14222<br>
                                                                                    Ramal: 1471 <br>
                                                                                    Tel: (24) 3365-5156 <br>
                                                                                    Email: asfp@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>7- Suzana Lyra Soares</strong><br>
                                                                                    Matrícula: 19878<br>
                                                                                    Ramal: 1485 <br>
                                                                                    Tel: (24) 3377-8310 <br>
                                                                                    Email: rh.tec@angra.rj.gov
                                                                                </li>
                                                                                <span class="py-3">Secretaria-Executiva de
                                                                                    Infraestrutura</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>8- Marcelo Casado Lima Sampaio Araújo
                                                                                    </strong><br>
                                                                                    Matrícula: 11776<br>
                                                                                    Ramal: 1075 <br>
                                                                                    Tel: (24) 3377-8652 <br>
                                                                                    Email: sad.sein@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>9- Maria da Glória Diniz
                                                                                        Rosa</strong><br>
                                                                                    Matrícula: 3837<br>
                                                                                    Ramal: 1072 <br>
                                                                                    Tel: (24) 3377-8731 <br>
                                                                                    Email: sad.ctil@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="saapHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#saapCollapse"
                                                                            aria-expanded="false" aria-controls="saapCollapse">
                                                                            Secretaria de Agricultura, Aquicultura e Pesca (SAAP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="saapCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="saapHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Jefferson Affonso Soares</strong><br>
                                                                                    Matrícula: 17802<br>
                                                                                    Ramal: 1854 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- André Luis Malvão de Sousa
                                                                                    </strong><br>
                                                                                    Matrícula: 3473<br>
                                                                                    Ramal: 1854 <br>

                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Geórgia dos Santos Domingos Maia
                                                                                    </strong><br>
                                                                                    Matrícula: 4502408<br>
                                                                                    Ramal: 1020 <br>

                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="scpHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#scpCollapse"
                                                                            aria-expanded="false" aria-controls="scpCollapse">
                                                                            Secretaria de Cultura e Patrimônio (SCP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="scpCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="scpHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Roberta Nakamashi</strong><br>
                                                                                    Matrícula: 30502<br>
                                                                                    E-mail: fundo.cultura@angra.rj.gov.br <br>
                                                                                    Telefone: (24) 3365-7200 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Samir Machado Lessa</strong><br>
                                                                                    Matrícula: 29586<br>
                                                                                    E-mail: coleta.cultura@angra.rj.gov.br <br>
                                                                                    Telefone: (24) 3365-7200 <br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sdeHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sdeCollapse"
                                                                            aria-expanded="false" aria-controls="sdeCollapse">
                                                                            Secretaria de Desenvolvimento Econômico (SDE)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sdeCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sdeHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Tânia Gomes da Silva</strong><br>
                                                                                    Matrícula: 19894<br>
                                                                                    Ramal: 1616 <br>
                                                                                    Tel: (24) 3365-0209<br>
                                                                                    Email: saeatendimento@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Josua Pereira de Lima
                                                                                        Junior</strong><br>
                                                                                    Matrícula: 1416<br>
                                                                                    Ramal: 4507 <br>
                                                                                    Tel: (24) 3377-4507<br>
                                                                                    Email: sde.decin@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sdrmambucabaHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#sdrmambucabaCollapse"
                                                                            aria-expanded="false"
                                                                            aria-controls="sdrmambucabaCollapse">
                                                                            Secretaria de Desenvolvimento Regional (SDR/Parque
                                                                            Mambucaba)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sdrmambucabaCollapse"
                                                                        class="accordion-collapse collapse"
                                                                        aria-labelledby="sdrmambucabaHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Helena Amaral de Souza</strong><br>
                                                                                    Matrícula: 22215<br>
                                                                                    Ramal: 1526 <br>
                                                                                    Tel: (24) 3362-3633 <br>
                                                                                    Email: sepm.adm@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Luciano Mattoso de Carvalho
                                                                                    </strong><br>
                                                                                    Matrícula: 17465<br>
                                                                                    Ramal: 1525 <br>
                                                                                    Tel: (24) 3362-6632<br>
                                                                                    Email: soh.sprs@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sdspbaHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#sdspbaCollapse" aria-expanded="false"
                                                                            aria-controls="sdspbaCollapse">
                                                                            Secretaria de Desenvolvimento Social e Promoção da
                                                                            Cidadania (SDSP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sdspbaCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sdspbaHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Arão de Assis Carrilho</strong><br>
                                                                                    Matrícula: 14522693788<br>
                                                                                    Ramal: 1240 <br>
                                                                                    Email: sdsp.ctvs@angra.rj.gov.br
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Ana Isabella Oliveira dos
                                                                                        Santos</strong><br>
                                                                                    Matrícula: ------<br>
                                                                                    Ramal: 1240 <br>
                                                                                    Email: sdsp@angra.rj.gov.br
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sdratgcHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#sdratgcCollapse" aria-expanded="false"
                                                                            aria-controls="sdratgcCollapse">
                                                                            Secretaria de Desenvolvimento Regional (SDR/ATGC)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sdratgcCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sdratgcHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Mariana de Souza Gomes</strong><br>
                                                                                    Matrícula: 28.895<br>
                                                                                    Ramal: 2754 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Hugo Marques Machado Ferreira
                                                                                    </strong><br>
                                                                                    Matrícula: 30.950<br>
                                                                                    Ramal: 1300 <br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sdrHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sdrCollapse"
                                                                            aria-expanded="false" aria-controls="sdrCollapse">
                                                                            Secretaria de Desenvolvimento Regional (SDR)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sdrCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sdrHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Fernanda Amaro Diniz</strong><br>
                                                                                    Matrícula: 11632<br>
                                                                                    Ramal: 1180 <br>
                                                                                    Tel: (24) 3379-9905 <br>
                                                                                    Email: sdr.contratos@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Gustavo da Silva Marinho</strong><br>
                                                                                    Matrícula: 29121<br>
                                                                                    Ramal: 1184 <br>
                                                                                    Tel: (24) 3365-0470 <br>
                                                                                    Email: Ilhagrande.ct@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sejinHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#sejinCollapse" aria-expanded="false"
                                                                            aria-controls="sejinCollapse">
                                                                            Secretaria de Educação, Juventude e Inovação (SEJIN)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sejinCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sejinHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Josimar de Santana Dias</strong><br>
                                                                                    Matrícula: 3770<br>
                                                                                    Ramal: 1663 <br>
                                                                                    Tel: (24) 3377-1897 <br>
                                                                                    Email: sect.aspra@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Raphael Carlos Pessanha do
                                                                                        Rosário</strong><br>
                                                                                    Matrícula: 17384<br>
                                                                                    Ramal: 9922 <br>
                                                                                    Tel: (24) 3379-9922 <br>
                                                                                    Email: sect.cocti@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="selHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#selCollapse"
                                                                            aria-expanded="false" aria-controls="selCollapse">
                                                                            Secretaria de Esporte e Lazer (SEL)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="selCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="selHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Felipe de Assis Teixeira</strong><br>
                                                                                    Matrícula: 11744<br>
                                                                                    Ramal: 3224 <br>
                                                                                    Tel: (24) 3365-3224 <br>
                                                                                    Email: projetosesportivos@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- TAISA DE OLIVEIRA S. G.
                                                                                        MONTEIRO</strong><br>
                                                                                    Matrícula: 30085<br>
                                                                                    Ramal: 3224 <br>
                                                                                    Tel: (24) 3365-3224 <br>
                                                                                    Email: esporte@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sevHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sevCollapse"
                                                                            aria-expanded="false" aria-controls="sevCollapse">
                                                                            Secretaria de Eventos (SEV)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sevCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sevHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Josuá P. de Lima Junior</strong><br>
                                                                                    Matrícula: 14166<br>
                                                                                    Tel: (24) 99833-1964 <br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Rubens Alves de Faria</strong><br>
                                                                                    Matrícula: 29670<br>
                                                                                    Tel: (24) 99989-5825 <br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sfiHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sfiCollapse"
                                                                            aria-expanded="false" aria-controls="sfiCollapse">
                                                                            Secretaria de Finanças (SFI)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sfiCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sfiHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Claudia Porto de Arroxelas
                                                                                        Bragança</strong><br>
                                                                                    Matrícula: 22299<br>
                                                                                    Ramal: 1086 <br>
                                                                                    Tel: (24) 3365-6472 <br>
                                                                                    Email: sfi.gt@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Bianca Luziane Queiroz
                                                                                        Godinho</strong><br>
                                                                                    Matrícula: 12359<br>
                                                                                    Ramal: 1768 <br>
                                                                                    Tel: (24) 3365-6466 <br>
                                                                                    Email: sfi.aci@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sgriHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sgriCollapse"
                                                                            aria-expanded="false" aria-controls="sgriCollapse">
                                                                            Secretaria de Governo e Relações Institucionais (SGRI)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sgriCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sgriHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Renan de Andrade Leone</strong><br>
                                                                                    Matrícula: 22391<br>
                                                                                    Ramal: 1116 <br>
                                                                                    Tel: (24) 3365-1234 <br>
                                                                                    Email: ouvidoria@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Jaqueline Ferreira de
                                                                                        Araújo</strong><br>
                                                                                    Matrícula: 32365<br>
                                                                                    Ramal: 1817 <br>
                                                                                    Tel: (24) 3365-7174 <br>
                                                                                    Email: governo.apoio03@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="siopHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#siopCollapse"
                                                                            aria-expanded="false" aria-controls="siopCollapse">
                                                                            Secretaria de Infraestrutura e Obras Públicas (SIOP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="siopCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="siopHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Carlos Jose Maia da
                                                                                        Rocha</strong><br>
                                                                                    Matrícula: 3731<br>
                                                                                    Ramal: 1313 <br>
                                                                                    Tel: (24) 3367-6468
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Zelimare Ribeiro do Nascimento
                                                                                        Bernardo</strong><br>
                                                                                    Matrícula: 13541<br>
                                                                                    Ramal: 1751 <br>
                                                                                    Tel: (24) 3368-5293
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="spdcHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#spdcCollapse"
                                                                            aria-expanded="false" aria-controls="spdcCollapse">
                                                                            Secretaria de Proteção e Defesa Civil (SPDC)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="spdcCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="spdcHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Carla Rosiane Lima</strong><br>
                                                                                    Matrícula: 11867<br>
                                                                                    Ramal: 1761 <br>
                                                                                    Tel: (24) 3377-6046 <br>
                                                                                    Email: defesacivil@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Gislaine de Oliveira Freitas da
                                                                                        Silva</strong><br>
                                                                                    Matrícula: 17946<br>
                                                                                    RAMAL: 1144 <br>
                                                                                    Tel: (24) 3377-6152 <br>
                                                                                    Email: administracaodc@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Maria de Fátima Meirelles
                                                                                        Salgado</strong><br>
                                                                                    Matrícula: 3307<br>
                                                                                    Ramal: 1142 <br>
                                                                                    Tel: (24) 3365-2213 <br>
                                                                                    Email: controleinternodc@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Maykon da Silva de
                                                                                        Oliveira</strong><br>
                                                                                    Matrícula: 11757<br>
                                                                                    Ramal: 1146 <br>
                                                                                    Tel: (24) 3377-8737 <br>
                                                                                    Email: engenhariadc@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>5- Giuliano Machado Costa</strong><br>
                                                                                    Matrícula: 11740<br>
                                                                                    Ramal: 1132 <br>
                                                                                    Tel: (24) 3377-9217 <br>
                                                                                    Email: operacoesdc@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sppHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sppCollapse"
                                                                            aria-expanded="false" aria-controls="sppCollapse">
                                                                            Secretaria de Planejamento e Parcerias (SPP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sppCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sppHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Maria Carolina Carvalho dos
                                                                                        Santos</strong><br>
                                                                                    Matrícula: 30845<br>
                                                                                    Ramal: 1212 <br>
                                                                                    Tel: (24) 3365-1212 <br>
                                                                                    Email: administrativo.pge@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Nilcineia Fonseca da Silva
                                                                                        Costa</strong><br>
                                                                                    Matrícula: 14154<br>
                                                                                    Ramal: 1269 <br>
                                                                                    Tel: (24) 3377-8319 <br>
                                                                                    Email: administrativoti@angra.rj.gov
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="ssaasgabHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse"
                                                                            data-bs-target="#ssaasgabCollapse" aria-expanded="false"
                                                                            aria-controls="ssaasgabCollapse">
                                                                            Secretaria Municipal de Saúde (SSA)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="ssaasgabCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="ssaasgabHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Thiago Omena de Carvalho</strong><br>
                                                                                    Matrícula: 14858<br>
                                                                                    Ramal: 1198 <br>
                                                                                    Tel: (24) 3364-4312 <br>
                                                                                    Email: fusarcpd@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Renata Fernandes Silva dos Santos
                                                                                        Braga</strong><br>
                                                                                    Matrícula: 26180<br>
                                                                                    Ramal: 1199 <br>
                                                                                    Tel: (24) 3379-9947 <br>
                                                                                    Email: renatafssbraga@gmail.com
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Lucas de Sousa
                                                                                        Nascimento</strong><br>
                                                                                    Matrícula: ------<br>
                                                                                    Ramal: 1012 <br>
                                                                                    Tel: (24) 3377-5856 <br>
                                                                                    Email: hmj.informatica@angra.rj.gov
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Girlene Teodoro de
                                                                                        Oliveira</strong><br>
                                                                                    Matrícula: 4502344<br>
                                                                                    Ramal: 228 <br>
                                                                                    Email: hmj.rh@angra.rj.gov
                                                                                </li>
                                                                            </ul>

                                                                            <!-- <ul class="list-group mb-4">
                                                                                <span class="py-3">SUAPR</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Gisele Cunha Paulo</strong><br>
                                                                                    Matrícula: 11186<br>
                                                                                    Ramal:  <br>
                                                                                    Tel:  <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Vania Correa Ribeiro</strong><br>
                                                                                    Matrícula: 29696<br>
                                                                                    Ramal: <br>
                                                                                    Tel:  <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUPCAR</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Vicente José Leitão Crisóstomo Júnior</strong><br>
                                                                                    Matrícula: 4500326<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Lídia Cunha da Rocha Balbino</strong><br>
                                                                                    Matrícula: 6347<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SEAPR</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>5- Renata Oliveira Jordão</strong><br>
                                                                                    Matrícula: 30681<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">ASGAB</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>6- Caroline Rodrigues Madureira</strong><br>
                                                                                    Matrícula: 13196<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>7- Elisabeth Maria Lopes Simões</strong><br>
                                                                                    Matrícula: 29979<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUGEH</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>8- Douglas Gomes Meireles Bitencout</strong><br>
                                                                                    Matrícula: 31860<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>9- Vivian Ribeiro Cunha de Moura</strong><br>
                                                                                    Matrícula: 31839<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUASA</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>10- Denise Santos Pires</strong><br>
                                                                                    Matrícula: 4798<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>11- Hele Serafim Filho</strong><br>
                                                                                    Matrícula: 13136<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUGER</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>12- Cristiane da Silva Costa</strong><br>
                                                                                    Matrícula: 11641<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>13- Monique Agnes Penha Siva Rocha</strong><br>
                                                                                    Matrícula: 26352<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>14- Hélio Fraga Meira de Bulhões</strong><br>
                                                                                    Matrícula: 4502337<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>15- Thiago de Pinho Fróes</strong><br>
                                                                                    Matrícula: 17555<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>16- Aline Luiz Machado Jorge</strong><br>
                                                                                    Matrícula: 4501598<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>17- Luciana da Silva Parente</strong><br>
                                                                                    Matrícula: 4502289<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>18- Victor Hugo Reis da Silva</strong><br>
                                                                                    Matrícula: 11688<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>19- Idivaldo Ferreira de Araújo</strong><br>
                                                                                    Matrícula: 30530<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>20- Rodrigo Nunes Almeida de Oliveira</strong><br>
                                                                                    Matrícula: 4501478<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li><li class="list-group-item">
                                                                                    <strong>21- Karina dos Santos Pereira</strong><br>
                                                                                    Matrícula: 28032<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li><li class="list-group-item">
                                                                                    <strong>22- Sandra da Conceição S. S de Oliveira</strong><br>
                                                                                    Matrícula: 4502271<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUAP</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>23- Paulo Ricardo Ferreira</strong><br>
                                                                                    Matrícula: 30872<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>24- Odorico Conceição Maia de Oliveira</strong><br>
                                                                                    Matrícula: 17430<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SEHMJ</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>25- Karine de Azevedo Carneiro da Silva</strong><br>
                                                                                    Matrícula: 7964<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>26- Livia Santos de Oliveira</strong><br>
                                                                                    Matrícula: 1137<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <span class="py-3">SUMP</span>
                                                                                <li class="list-group-item">
                                                                                    <strong>27- Danilo de Lima Sírio Reis</strong><br>
                                                                                    Matrícula: 31941<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>28- Lucas Felipe Dourado Fontella</strong><br>
                                                                                    Matrícula: 27128<br>
                                                                                    Ramal: <br>
                                                                                    Tel: <br>
                                                                                    Email:
                                                                                </li>
                                                                            </ul> -->

                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="sspHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#sspCollapse"
                                                                            aria-expanded="false" aria-controls="sspCollapse">
                                                                            Secretaria de Segurança Pública (SSP)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="sspCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="sspHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Anisio Soares de Araujo
                                                                                        Filho</strong><br>
                                                                                    Matrícula: 29525<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Alvanir Eleutério dos Anjos</strong><br>
                                                                                    Matrícula: 4516<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>3- Amanda Araújo Lage de
                                                                                        Gusmão</strong><br>
                                                                                    Matrícula: 29535<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>4- Anna Paula Nascimento Pereira da
                                                                                        Silva</strong><br>
                                                                                    Matrícula: 29251<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>5- Alessandro Campos do
                                                                                        Nascimento</strong><br>
                                                                                    Matrícula: 29512<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>6- Aronildo Ferreira Gonçalves</strong><br>
                                                                                    Matrícula: 3476<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>7- Cláudio Trindade de Souza</strong><br>
                                                                                    Matrícula: 70190662<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>8- Dulcineia Gil da Silva</strong><br>
                                                                                    Matrícula: 21819<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>9- Giovanni Rodrigues Ferreira</strong><br>
                                                                                    Matrícula: 4502290<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>10- Jabez Filipe Silva de
                                                                                        Castro</strong><br>
                                                                                    Matrícula: 22364<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>11- José Aparecido da Silva Luis
                                                                                        Santos</strong><br>
                                                                                    Matrícula: 10878<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>12- Juanita Nascimento da Silva</strong><br>
                                                                                    Matrícula: 17387<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>13- Ozéas Treva</strong><br>
                                                                                    Matrícula: 11772<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>14- Rafael Fonseca e Souza</strong><br>
                                                                                    Matrícula: 13342<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>15- Rodrigo Clymaco Marques</strong><br>
                                                                                    Matrícula: 10346<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>16- Sandra Márcia Ribeiro dos
                                                                                        Santos</strong><br>
                                                                                    Matrícula: 21646<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>17- Wolner Góes do Rosário</strong><br>
                                                                                    Matrícula: 19656<br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>

                                                                <!-- SECREATARIA - PONTO FOCAL ACCORDION -->
                                                                <div class="accordion-item">
                                                                    <h2 class="accordion-header" id="supjHeader">
                                                                        <button class="accordion-button fw-bold" type="button"
                                                                            data-bs-toggle="collapse" data-bs-target="#supjCollapse"
                                                                            aria-expanded="false" aria-controls="supjCollapse">
                                                                            Secretaria de Urbanização, Parques e Jardins (SUPJ)
                                                                        </button>
                                                                    </h2>
                                                                    <div id="supjCollapse" class="accordion-collapse collapse"
                                                                        aria-labelledby="supjHeader"
                                                                        data-bs-parent="#instituicoesAccordion">
                                                                        <div class="accordion-body">
                                                                            <ul class="list-group mb-4">
                                                                                <li class="list-group-item">
                                                                                    <strong>1- Leandro Corrêa
                                                                                    </strong><br>
                                                                                    Matrícula: 27931<br>
                                                                                    Tel: (24) 3365-6522<br>
                                                                                    Ramal: 6522<br>
                                                                                    E-mail: sdeus.sepas@angra.rj.gov.br<br>
                                                                                </li>
                                                                                <li class="list-group-item">
                                                                                    <strong>2- Lordilene Eugênio</strong><br>
                                                                                    Matrícula: 27978<br>
                                                                                    Tel: (24) 3365-6522<br>
                                                                                    Ramal: 6522<br>
                                                                                    E-mail: sdeus.sepas@angra.rj.gov.br<br>
                                                                                </li>
                                                                            </ul>
                                                                        </div>
                                                                    </div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div id="restantePerguntas" style="display: none;">
                                        <h3 class="lead">Usuários</h3>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading04">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse04"
                                                    aria-expanded="false" aria-controls="flush-collapse04">
                                                    Quem são os usuários do SEI? </button>
                                            </h2>
                                            <div id="flush-collapse04" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading04" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Poderão utilizar o sistema, desde que autorizados pelas chefias da unidades,
                                                        os
                                                        servidores, funcionários contratados, estagiários e futuramente usuário
                                                        externos.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading05">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse05"
                                                    aria-expanded="false" aria-controls="flush-collapse04">
                                                    Como solicitar meu Cadastro no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse05" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading05" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Para obter sua conta no SEI, você deve dirigir-se a um <strong>Ponto Focal
                                                            SEI</strong> do seu departamento e solicitar a ele a criação de seu
                                                        usuário.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading06">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse06"
                                                    aria-expanded="false" aria-controls="flush-collapse06">
                                                    Qual será o meu login e a minha senha no SEI (Treinamento e
                                                    Produção)? </button>
                                            </h2>
                                            <div id="flush-collapse06" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading06" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Para acessar o SEI da PMAR basta acessar o endereço eletrônico
                                                        (<a href="https://angra.sei.rj.gov.br" class="link-sei"
                                                            target="_blank">https://angra.sei.rj.gov.br</a>) utilizando a matrícula
                                                        de
                                                        servidor como login e
                                                        senha da rede interna da Prefeitura (usada para ligar seu Computador), logo
                                                        após, selecione o
                                                        órgão/secretaria.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading07">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse07"
                                                    aria-expanded="false" aria-controls="flush-collapse07">
                                                    Como é o acesso ao SEI? </button>
                                            </h2>
                                            <div id="flush-collapse07" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading07" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        O usuário interno deve entrar na página inicial do SEI
                                                        (<a href="https://angra.sei.rj.gov.br" class="link-sei"
                                                            target="_blank">https://angra.sei.rj.gov.br</a>), inserir seu login,
                                                        senha
                                                        e orgão. O ícone para
                                                        acesso ao sistema também está disponível no sítio da PMAR através do
                                                        endereço
                                                        eletrônico (<a href="https://angra.rj.gov.br/sei" class="link-sei"
                                                            target="_blank">https://angra.rj.gov.br/sei</a>).
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading08">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse08"
                                                    aria-expanded="false" aria-controls="flush-collapse08">
                                                    Todos os usuários têm assinatura eletrônica? Como funciona? </button>
                                            </h2>
                                            <div id="flush-collapse08" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading08" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Todos os servidores da Prefeitura têm assinatura eletrônica. Basta informar
                                                        a
                                                        senha de login da rede, escolhendo o cargo adequado.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading09">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse09"
                                                    aria-expanded="false" aria-controls="flush-collapse09">
                                                    É possível uma pessoa redigir um documento e outra assinar? </button>
                                            </h2>
                                            <div id="flush-collapse09" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading09" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Sim. Os usuários podem assinar documentos de processos que estiverem
                                                        tramitando
                                                        em sua unidade, mesmo que redigidos por outro servidor.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading10">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse10"
                                                    aria-expanded="false" aria-controls="flush-collapse10">
                                                    Há modelos padronizados de documentos? </button>
                                            </h2>
                                            <div id="flush-collapse10" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading10" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Sim. Caso queira acrescentar mais algum modelo favor entrar em contato com
                                                        seu
                                                        Ponto Focal.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading11">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse11"
                                                    aria-expanded="false" aria-controls="flush-collapse11">
                                                    Como iniciar/criar um processo no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse11" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading11" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Na tela principal do SEI, no menu lateral à esquerda, clique em “Iniciar
                                                        Processo”. Em seguida, selecione o tipo de processo e preencha os campos da
                                                        tela
                                                        de “Iniciar processo”.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading12">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse12"
                                                    aria-expanded="false" aria-controls="flush-collapse12">
                                                    Como cadastrar um documento? </button>
                                            </h2>
                                            <div id="flush-collapse12" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading12" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Clique sobre o número do processo desejado. Clique no ícone "Incluir
                                                        Documento".
                                                        Escolha na lista o tipo de documento desejado. Digite as informações de
                                                        identificação do documento.

                                                    <ul>
                                                        <li>
                                                            <strong>Texto inicial:</strong> Para um documento em branco, selecione a
                                                            opção "Nenhum". (Para mais informações sobre como usar documentos e
                                                            textos
                                                            cadastrados acesse:
                                                            "Criar texto padrão" e "Criar documento modelo" ).
                                                        </li>
                                                        <li>
                                                            <strong>Descrição ( opcional ):</strong> Digite o assunto do documento.
                                                        </li>
                                                        <li>
                                                            <strong>Nome na árvore:</strong> Complementação do nome do documento.
                                                        </li>
                                                        <li>
                                                            <strong>Interessados:</strong> Por padrão, o sistema preencherá
                                                            automaticamente com os interessados cadastrados no processo. Caso queira
                                                            adicionar interessados,
                                                            digite parte do nome do interessado, e:
                                                        </li>
                                                        <ul>
                                                            <li>Se o interessado for exibido: clique sobre o nome do interessado.
                                                            </li>
                                                            <li>Se o interessado não for exibido: Digite o nome completo, tecle
                                                                "enter"
                                                                e clique em "Ok".</li>
                                                        </ul>
                                                        <li><strong>Destinatários ( opcional ):</strong> Digite o destinatário do
                                                            documento.</li>
                                                        <li><strong>Classificação por assuntos:</strong> É automaticamente
                                                            preenchido, e
                                                            <span class="text-decoration-underline">não deve ser alterado</span>.
                                                        </li>
                                                        <li><strong>Observação desta Unidade ( opcional )</strong>: É um campo de
                                                            livre
                                                            preenchimento, onde devem ser inseridas informações que facilitem a
                                                            identificação do processo.
                                                            Essas informações podem ser recuperadas na pesquisa exclusivamente pela
                                                            unidade
                                                            que as inseriu.</li>
                                                        <li><strong>Nível de acesso:</strong> Permite definir o nível de acesso
                                                            global
                                                            do processo, se "sigiloso", se "restrito" ou se "público".</li>
                                                    </ul>
                                                    <p>Clique em "Salvar". O documento aparecerá na árvore do processo.</p>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading13">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse13"
                                                    aria-expanded="false" aria-controls="flush-collapse13">
                                                    Como os processos tramintam no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse13" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading13" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Depois de iniciar um processo e incluir todos os documentos necessários,
                                                        basta
                                                        enviá-lo à unidade respectiva. A tramitação é eletrônica, por isso o
                                                        processo é
                                                        instantaneamente recebido pela outra unidade, para que ela faça a análise e
                                                        os
                                                        despachos necessários por meio do SEI.
                                                    </p>
                                                    <p>
                                                        É possível enviar um processo a mais de uma unidade ao mesmo tempo, caso
                                                        elas
                                                        não dependam umas das outras para dar os devidos despachos a esse processo e
                                                        ainda manter o processo aberto na unidade de origem.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading14">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse14"
                                                    aria-expanded="false" aria-controls="flush-collapse14">
                                                    Como um documento eletrônico é assinado? Os documentos podem ficar sem
                                                    assinatura? </button>
                                            </h2>
                                            <div id="flush-collapse14" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading14" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        No SEI, qualquer servidor cadastrado no sistema pode assinar um documento
                                                        eletronicamente. Isso é feito por meio de uso de senha ou de certificação
                                                        digital. A senha é de uso pessoal e intransferível, e deve ser mantida em
                                                        sigilo
                                                        por cada servidor nenhum servidor pode utilizar a senha de outro. Por isso,
                                                        guarde bem sua senha! Os documentos de um processo podem ser assinados por
                                                        mais
                                                        de um servidor, sem que necessariamente haja uma hierarquia de assinaturas.
                                                        Para
                                                        que um documento seja assinado por várias pessoas, ele deve ser ncluído num
                                                        Bloco de Assinaturas no SEI.
                                                    </p>
                                                    <p>
                                                        O bloco deve ser disponibilizado às unidades que devem assinar o documento.
                                                        Ele
                                                        funciona como uma “pasta” que reúne e organiza despachos e permite que a
                                                        chefia
                                                        de sua unidade ou de outras unidades assinem qualquer documento que tenha
                                                        sido
                                                        criado por sua unidade.
                                                    </p>
                                                    <p>
                                                        Se um processo enviado a outra unidade contiver um documento sem assinatura,
                                                        o
                                                        conteúdo desse documento não poderá ser visualizado pela unidade que o
                                                        recebeu.
                                                        Trata-se de uma minuta. Por isso, é necessário assinar os documentos no SEI
                                                        antes de enviar o processo a outra unidade.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading15">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse15"
                                                    aria-expanded="false" aria-controls="flush-collapse15">
                                                    Quem pode autuar processos eletrônicos? </button>
                                            </h2>
                                            <div id="flush-collapse15" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading15" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Todos os usuários podem autuar processos eletrônicos em suas unidades.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading16">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse16"
                                                    aria-expanded="false" aria-controls="flush-collapse16">
                                                    O SEI possui acessibilidade? </button>
                                            </h2>
                                            <div id="flush-collapse16" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading16" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        A disponibilização de mecanismos de acessibilidade no SEI pode ser realizada
                                                        ativando a opção "Ativar recursos de acessibilidade" no cadastro do usuário.
                                                        Para realizar essa ativação, a Unidade Setorial deverá acessar o menu
                                                        "Administração > Usuários > Listar" do SEI, consultar o usuário para
                                                        alteração,
                                                        selecionar a opção "Alterar Usuário" e marcar a opção "Ativar recursos de
                                                        acessibilidade".
                                                    </p>
                                                    <p>
                                                        Importante frisar que, para o pleno funcionamento e ativação dos recursos de
                                                        acessibilidade, é necessária também a configuração das opções de "Facilidade
                                                        de
                                                        Acesso" no computador do usuário. No sistema operacional Windows essas
                                                        opções
                                                        estão disponíveis no "Painel de Controle", opção "Facilidade de Acesso ->
                                                        Central de Facilidade de Acesso". Ao acessar essa Central, deverão ser
                                                        selecionadas as opções pertinentes às necessidades especiais do usuário.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <h3 class="lead">Transição</h3>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading17">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse17"
                                                    aria-expanded="false" aria-controls="flush-collapse17">
                                                    Os processos antigos serão digitalizados? </button>
                                            </h2>
                                            <div id="flush-collapse17" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading17" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Inicialmente os processos antigos não serão incluídos no SEI.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading18">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse18"
                                                    aria-expanded="false" aria-controls="flush-collapse18">
                                                    Vai ser necessária a digitalização de algum documento? </button>
                                            </h2>
                                            <div id="flush-collapse18" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading18" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Sim, em duas as situações:
                                                    <ol>
                                                        <li>O documento que chegar ao protocolo será digitalizado e inserido no SEI
                                                            até
                                                            o dia 08/02/2024 conforme o artigo primeiro, parágrafo único e inciso
                                                            III do
                                                            Decreto Municipal Nº 13.367, de 03 de janeiro de 2024 criando-se um
                                                            processo
                                                            ou inserindo-o em um processo SEI já existente. Tanto o processo
                                                            eletrônico
                                                            gerado quanto o documento físico (que foi digitalizado) serão
                                                            encaminhados à
                                                            área competente;
                                                        </li>
                                                        <li>Quando um processo físico já arquivado for receber novo impulso
                                                            (documentos
                                                            novos para análise), deverá ser digitalizado e inserido no SEI como
                                                            processo
                                                            eletrônico.
                                                    </ol>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading19">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse19"
                                                    aria-expanded="false" aria-controls="flush-collapse19">
                                                    O que ocorrerá com o sistema anterior/legado (PRODATA)? </button>
                                            </h2>
                                            <div id="flush-collapse19" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading19" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Será utilizado apenas para consulta ou trâmite dos processos físicos
                                                        arquivados
                                                        encaminhados meramente para consulta.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <h3 class="lead">Dúvidas</h3>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading20">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse20"
                                                    aria-expanded="false" aria-controls="flush-collapse20">
                                                    Em caso de dúvidas quanto ao uso do SEI, a quem devo recorrer? </button>
                                            </h2>
                                            <div id="flush-collapse20" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading20" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Devem ser procurados os Pontos Focais de cada Secretaria, que são os
                                                        servidores
                                                        já designados para auxiliar os colaboradores quanto ao uso da ferramenta,
                                                        para
                                                        sanar as dúvidas.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <h3 class="lead">Perguntas Gerais</h3>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading21">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse21"
                                                    aria-expanded="false" aria-controls="flush-collapse21">
                                                    Qual navegador devo utilizar para acessar o SEI? </button>
                                            </h2>
                                            <div id="flush-collapse21" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading21" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        O sistema tem função multibrowser, entretanto, fica a sugestão pelos
                                                        navegadores
                                                        Chrome e Firefox, que apresentam melhor rendimento. O Internet Explorer tem
                                                        apresentado inconsistências, portanto, evite o seu uso.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading22">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse22"
                                                    aria-expanded="false" aria-controls="flush-collapse22">
                                                    Existe algum custo pela utilização? O programa é cedido
                                                    gratuitamente? </button>
                                            </h2>
                                            <div id="flush-collapse22" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading22" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        O programa é cedido gratuitamente, sem custos, através da celebração do
                                                        Acordo
                                                        de Cooperação Técnica nº 2/2023. entre o Estado do Rio de Janeiro por meio
                                                        da
                                                        Secretaria de transformação Digital e a PMAR.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading23">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse23"
                                                    aria-expanded="false" aria-controls="flush-collapse23">
                                                    Como os processos tramintam no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse23" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading23" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Depois de iniciar um processo e incluir todos os documentos necessários,
                                                        basta
                                                        enviá-lo à unidade respectiva através do botão de “Enviar Processo”. A
                                                        tramitação é eletrônica, por isso o processo é instantaneamente recebido
                                                        pela
                                                        outra unidade, para que ela faça a análise e os despachos necessários por
                                                        meio
                                                        do SEI.
                                                    </p>
                                                    <p>
                                                        É possível enviar um processo a mais de uma unidade ao mesmo tempo, caso
                                                        elas
                                                        não dependam umas das outras para dar os devidos despachos a esse processo.
                                                        Também é possível encaminhar mais de um processo ao mesmo tempo, desde que,
                                                        os
                                                        processos sejam encaminhados para a mesma unidade.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading24">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse24"
                                                    aria-expanded="false" aria-controls="flush-collapse24">
                                                    Como um documento eletrônico é assinado? Os documentos podem ficar sem
                                                    assinatura? </button>
                                            </h2>
                                            <div id="flush-collapse24" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading24" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        No SEI, qualquer servidor cadastrado no sistema pode assinar um documento
                                                        eletronicamente. Isso é feito por meio de uso de senha. A senha é de uso
                                                        pessoal
                                                        e intransferível, e deve ser mantida em sigilo por cada servidor – nenhum
                                                        servidor pode utilizar a senha de outro. Por isso, guarde bem sua senha!
                                                    </p>
                                                    <p>
                                                        Os documentos de um processo podem ser assinados por mais de um servidor,
                                                        sem
                                                        que necessariamente haja uma hierarquia de assinaturas. Para que um
                                                        documento
                                                        seja assinado por várias pessoas, ele deve ser incluído num Bloco de
                                                        Assinaturas
                                                        no SEI. O bloco deve ser disponibilizado às unidades que devem assinar o
                                                        documento.
                                                    </p>
                                                    <p>
                                                        Ele funciona como uma “pasta” que reúne e organiza despachos, e permite a
                                                        assinatura de qualquer documento que tenha sido criado por sua unidade. e
                                                        permite que a chefia de sua unidade ou de outras unidades assinem qualquer
                                                        documento que tenha sido criado por sua unidade.
                                                    </p>
                                                    <p>
                                                        Se um processo enviado à outra unidade contiver um documento sem assinatura,
                                                        o
                                                        conteúdo desse documento não poderá ser visualizado pela unidade que o
                                                        recebeu.
                                                        Trata-se de uma minuta. Por isso, é necessário assinar os documentos no SEI
                                                        antes de enviar o processo à outra unidade. Para mais informações, consulte
                                                        o
                                                        manual do usuário.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading25">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse25"
                                                    aria-expanded="false" aria-controls="flush-collapse25">
                                                    Caso a sua questão esteja contemplada neste FAQ: </button>
                                            </h2>
                                            <div id="flush-collapse25" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading25" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Envie sua pergunta para nosso canal de atendimento ao usuário externo: <span
                                                            class="text-primary">sei@angra.rj.gov.br</span>.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading26">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse26"
                                                    aria-expanded="false" aria-controls="flush-collapse26">
                                                    A minha unidade poderá ter um usuário e senha? </button>
                                            </h2>
                                            <div id="flush-collapse26" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading26" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Não. Os acessos ao SEI são pessoais e intransferíveis, não sendo possível
                                                        acessar o sistema através do e-mail da unidade.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading27">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse27"
                                                    aria-expanded="false" aria-controls="flush-collapse27">
                                                    Quais são as formas de assinar documentos no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse27" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading27" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Há 3 (três) formas de assinar documentos no SEI:

                                                    <ul>
                                                        <li>Por usuários da própria unidade;</li>
                                                        <li>Por usuários de outras unidades através de bloco de assinaturas; e/ou
                                                        </li>
                                                        <li>Por usuários externos.</li>
                                                    </ul>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading28">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse28"
                                                    aria-expanded="false" aria-controls="flush-collapse28">
                                                    Como editar um documento produzido no SEI? </button>
                                            </h2>
                                            <div id="flush-collapse28" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading28" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        É possível editar apenas documentos que foram produzidos pela sua unidade e
                                                        que
                                                        ainda não foram assinados e não foram acessados por terceiros (usuários de
                                                        outras unidades ou através da Pesquisa Pública). Para editar um documento, o
                                                        usuário deve:

                                                    <ul>
                                                        <li> Entrar no processo desejado (clicar sobre o NUP do processo);</li>
                                                        <li> Clicar sobre o documento desejado na árvore do processo (lateral
                                                            esquerda
                                                            da tela);</li>
                                                        <li> Clicar no ícone “Editar Conteúdo”;</li>
                                                        <li> Realizar as alterações desejadas;</li>
                                                        <li> Clicar no botão “Salvar” (canto superior esquerdo da tela).</li>
                                                    </ul>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading29">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse29"
                                                    aria-expanded="false" aria-controls="flush-collapse29">
                                                    Não possuo login/senha do SEI-Angra dos Reis. Como solicitar? </button>
                                            </h2>
                                            <div id="flush-collapse29" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading29" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        No caso de um usuário interno o acesso poderá ser solicitado para o Ponto
                                                        Focal
                                                        da unidade / secretaria ou através do e-mail: <span
                                                            class="text-primary">sei@angra.rj.gov.br</span>.
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="accordion-item">
                                            <h2 class="accordion-header" id="flush-heading30">
                                                <button class="accordion-button collapsed text-dark" type="button"
                                                    data-bs-toggle="collapse" data-bs-target="#flush-collapse30"
                                                    aria-expanded="false" aria-controls="flush-collapse30">
                                                    Como saber se um processo foi recebido na minha unidade? </button>
                                            </h2>
                                            <div id="flush-collapse30" class="accordion-collapse collapse"
                                                aria-labelledby="flush-heading30" data-bs-parent="#accordionFlushExample">
                                                <div class="accordion-body">
                                                    <p>
                                                        Para identificar se um processo foi ou não recebido em sua unidade, basta
                                                        verificar a cor em que se encontra seu número na tela de controle de
                                                        processos:
                                                    </p>
                                                    <p>
                                                    <ul>
                                                        <li><span class="text-danger">Cor vermelha</span> significa que o processo
                                                            ainda
                                                            não foi
                                                            recebido na Unidade, ou seja, nenhum usuário da Unidade acessou o
                                                            processo.
                                                        </li>
                                                        <li><span class="text-dark">Cor preta</span> significa
                                                            que o processo já foi acessado por
                                                            algum usuário da unidade. Para identificar o recebedor, consulte o
                                                            andamento
                                                            do
                                                            processo.</li>
                                                        <li><span class="text-primary">Cor azul</span> significa que o processo foi
                                                            acessado pelo
                                                            usuário logado que visualiza a cor azul.</li>
                                                    </ul>
                                                    <p>Para acusar o recebimento de um processo, basta clicar no número do processo
                                                        que
                                                        estiver na cor vermelha e seu registro automaticamente aparecerá no
                                                        andamento do
                                                        processo. Para visualizar, clique em “Consultar Andamento”.</p>
                                                    </p>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="col-12 text-center">
                                        <button id="buttonFAQ" onclick="mostrarRestante()" class="btn btn-primary mt-3 mb-5">
                                            <i class="fa-solid fa-plus"></i> &nbsp;
                                            Mostrar Mais Perguntas
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>


                <!-- <section id="atas-comite">
                    <div class="container mb-5">
                        <div class="row">
                            <div class="col-12 p-3 text-center">
                                <h1>Comitê Gestor</h1>
                            </div>
                        </div>
                        <div class="row justify-content-center align-items-center g-2">
                            <div
                                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">

                                <div class="my-5">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user mr-5"></i>&nbsp;&nbsp;Presidente</strong>: Rogério de Almeida Pontes <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 28934 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Vice-Presidente</strong>: Emidio Marinho da Silva Filho <br>
                                                <strong>Órgão</strong>: CGM <br>
                                                <strong>Matrícula</strong>: 2769 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Secretária</strong>: Bárbara Di Sarli de Carvalho <br>
                                                <strong>Órgão</strong>: PGM <br>
                                                <strong>Matrícula</strong>: 29639 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Lucas Soares dos Santos <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 28714 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Daniel Silva de Azevedo <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 19183 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Matheus Silva Lopes <br>
                                                <strong>Órgão</strong>: PGM <br>
                                                <strong>Matrícula</strong>: 29514 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: João Vitor Costa da Silva Carvalho  <br>
                                                <strong>Órgão</strong>: CGM <br>
                                                <strong>Matrícula</strong>: 28249 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                            </div>
                        </div>
                    </div>
                </section> -->


                <!-- Basic features section-->
                <section id="legislacao">
                    <div class="container px-5">

                        <div class="row justify-content-center align-items-center g-2">
                            <div
                                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">

                                <h2 class="display-4 lh-1 mb-4 my-3">Legislação</h2>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1816---Ed.-Extra_de_03-01-2024.pdf"
                                            target="_blank"><strong>Decreto Nº 13.367, de 03 de Janeiro de 2024 <i
                                                    class="bi-save2-fill me-2"></i></strong></a><br>
                                        Estabelece o regulamento do Processo Eletrônico do município de Angra dos Reis.<br>
                                        <small>Boletim Oficial N° 1816, página 14.</small>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1842_de_09-02-2024.pdf"
                                            target="_blank"><strong>Decreto Nº 13.409, de 09 de Fevereiro de 2024 <i
                                                    class="bi-save2-fill me-2"></i></strong></a><br>
                                        Prorroga o prazo disposto no art. 21 do decreto Nº 13.367, de 03 de Janeiro de 2024.<br>
                                        <small>Boletim Oficial N° 1842, página 72.</small>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1748_de_23-02-2024.pdf"
                                            target="_blank"><strong>Decreto Nº 13.423, de 23 de Fevereiro de 2024 <i
                                                    class="bi-save2-fill me-2"></i></strong></a><br>
                                        Institui o Comitê Gestor do Sistema Eletrônico de Informações, os Pontos Focais e dispõe
                                        sobre a produção e tramitação eletrônica de documentos e processos administrativos na
                                        administração pública municipal e dá outras providências.<br>
                                        <small>Boletim Oficial N° 1848, página 87.</small>
                                    </p>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-3 mb-lg-0">
                                        <a href="assets/docs/membros-cgsei.pdf" target="_blank"><strong>Portaria Nº 004/2024 -
                                                Designação de Comissão de Fiscalização, de 23 de Fevereiro de 2024 <i
                                                    class="bi-save2-fill me-2"></i></strong></a><br>
                                        Designa o Comitê Gestor do SEI-ANGRA (CGSEI), grupo que possui caráter estratégico, composto
                                        por membros da Superintendência de Tecnologia da Informação (SPP.SUTIN), Controladoria-Geral
                                        (CGM) e da Procuradoria-Geral (PGM) e tem como objetivo o gerenciamento e o acompanhamento
                                        do Sistema Eletrônico de Informações (SEI-ANGRA) no Município de Angra dos Reis.<br>
                                        <small> B.O. Nº 1848 de Fevereiro de 2024, página 110.</small>
                                    </p>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1858_de_14-03-2024.pdf"
                                            target="_blank"><strong>Decreto Nº 13.445 - Prorrogação de prazo para obrigatoriedade de
                                                Processos de Despesa em meio Eletrônico, de 14 de Março de 2024 <i
                                                    class="bi-save2-fill me-2"></i></strong></a><br>
                                        Prorroga o prazo disposto no Artigo 21 do Decreto Nº 13.367, de Janeiro de 2024.<br>
                                        <small> B.O. Nº 1858 de 14 de Março de 2024, página 27.</small>
                                    </p>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1931_de_25-07-2024.pdf"
                                            target="_blank"><strong>Portaria Nº 001/2024, de 25 de Julho de 2024
                                                <i class="bi-save2-fill me-2"></i></strong></a><br>
                                        A presidência da Câmara Municipal de Angra
                                        Dos Reis, no uso de suas atribuições legais, resolve estabelecer o regulamento do processo
                                        eletrônico.<br>
                                        <small> B.O. Nº 1931 de 25 de Julho de 2024, página 19.</small>
                                    </p>
                                </div>

                                <div class="my-5">
                                    <p class="fw-normal text-muted mb-lg-0">
                                        <a href="https://angra.rj.gov.br/downloads/bo/BO-1933_de_30-07-2024.pdf"
                                            target="_blank"><strong>Portaria Nº 002/2024, de 30 de Julho de 2024
                                                <i class="bi-save2-fill me-2"></i></strong></a><br>
                                        A presidência da Câmara Municipal de Angra
                                        dos Reis, no uso de suas atribuições legais, resolve instituir os Pontos Focais, bem como
                                        dispor sobre a produção e tramitação eletrônica de documentos e processos administrativos na
                                        Câmara Municipal de Angra dos Reis <br>
                                        <small> B.O. Nº 1933 de 30 de Julho de 2024, página 83.</small>
                                    </p>
                                </div>

                            </div>
                            <div class="col-4 order-0 order-sm-0 order-md-0 order-lg-2 order-xl-2 order-xxl-2">
                                <div>
                                    <div class="px-5 px-sm-0"><img class="img-fluid rounded-circle" src="assets/img/maoredonda.png"
                                            alt="Ilustração de alguém utilizando meios digitais." /></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>
                <!-- Call to action section-->



                <section class="bg-light" id="atas-comite">
                    <div class="container mb-5">
                        <div class="row">
                            <div class="col-12 p-3 text-center">
                                <h1>Comitê Gestor</h1>
                            </div>
                        </div>
                        <div class="row justify-content-center align-items-center g-2">
                            <div
                                class="col-12 col-sm-12 col-md-12 col-lg-8 col-xl-8 col-xl-8 order-1 order-sm-1 order-md-1 order-lg-0 order-xl-0 order-xxl-0">

                                <div class="my-5">
                                    <div class="row justify-content-center">
                                        <div class="col-md-6 mx-auto">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user mr-5"></i>&nbsp;&nbsp;Presidente</strong>:
                                                Rogério de Almeida Pontes <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 28934 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Vice-Presidente</strong>:
                                                Emidio Marinho da Silva Filho <br>
                                                <strong>Órgão</strong>: CGM <br>
                                                <strong>Matrícula</strong>: 2769 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row justify-content-center">
                                        <div class="col-md-6 mx-auto">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Secretária</strong>: Bárbara
                                                Di Sarli de Carvalho <br>
                                                <strong>Órgão</strong>: PGM <br>
                                                <strong>Matrícula</strong>: 29639 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Lucas Soares
                                                dos Santos <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 28714 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row justify-content-center">
                                        <div class="col-md-6 mx-auto">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Daniel Silva
                                                de Azevedo <br>
                                                <strong>Órgão</strong>: SPP <br>
                                                <strong>Matrícula</strong>: 19183 <br>
                                            </p>
                                        </div>
                                        <div class="col-md-6">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: Matheus Silva
                                                Lopes <br>
                                                <strong>Órgão</strong>: PGM <br>
                                                <strong>Matrícula</strong>: 29514 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                                <div class="my-5">
                                    <div class="row justify-content-center">
                                        <div class="col-md-6 mx-auto">
                                            <p class="fw-normal mb-3 mb-lg-0 text-center">
                                                <strong><i class="fa-regular fa-user"></i>&nbsp;&nbsp;Membro</strong>: João Vitor
                                                Costa da Silva Carvalho <br>
                                                <strong>Órgão</strong>: CGM <br>
                                                <strong>Matrícula</strong>: 28249 <br>
                                            </p>
                                        </div>
                                    </div>
                                </div>

                            </div>
                        </div>

                        <div class="row">
                            <div class="col-md-6">
                                <div class="p-3">
                                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                                        style="color: #696969; cursor: pointer;">
                                        Atas de Reunião
                                        <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                                    </h3>
                                    <div class="content d-none">
                                        <div class="mt-5 mb-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3431"
                                                    target="_blank"><strong>Nº 001/2024, <span style="color: #696969;">de 7 de Março de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3437"
                                                    target="_blank"><strong>Nº 002/2024, <span style="color: #696969;">de 7 de Março de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=3800"
                                                    target="_blank"><strong>Nº 003/2024, <span style="color: #696969;">de 11 de Março de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=6526"
                                                    target="_blank"><strong>Nº 004/2024, <span style="color: #696969;">de 15 de Março de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=7531"
                                                    target="_blank"><strong>Nº 005/2024, <span style="color: #696969;">de 19 de Março de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=34324"
                                                    target="_blank"><strong>Nº 006/2024, <span style="color: #696969;">de 20 de Maio de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=77901"
                                                    target="_blank"><strong>Nº 007/2024, <span style="color: #696969;">de 05 de Agosto de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=116957"
                                                    target="_blank"><strong>Nº 008/2024, <span style="color: #696969;">de 20 de Setembro de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=3415&id_documento=118357"
                                                    target="_blank"><strong>Nº 009/2024, <span style="color: #696969;">de 23 de Setembro de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="p-3">
                                    <h3 class="text-center toggle-content d-flex align-items-center justify-content-center"
                                        style="color: #696969; cursor: pointer;">
                                        Pareceres
                                        <i class="bi bi-chevron-down ms-3 toggle-arrow"></i>
                                    </h3>
                                    <div class="content d-none">
                                        <div class="mt-5 mb-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162463"
                                                    target="_blank"><strong>Parecer 1, <span style="color: #696969;">de 30 de Outubro de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                        <div class="my-3">
                                            <p class="fw-normal text-muted mb-lg-0">
                                                <a href="http://angra.sei.rj.gov.br/sei//controlador.php?acao=procedimento_trabalhar&id_procedimento=125097&id_documento=162579"
                                                    target="_blank"><strong>Parecer 2, <span style="color: #696969;">de 30 de Outubro de 2024</span>
                                                        <i class="bi-save2-fill me-2"></i></strong></a><br>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </section>


                <section class="cta">
                    <div class="cta-content">
                        <div class="container px-5">
                            <h2 class="text-white display-1 lh-1 mb-4">
                                Sistema Eletrônico de Informações
                            </h2>
                            <a class="btn btn-outline-light py-3 px-4 rounded-pill" href="https://angra.sei.rj.gov.br/"
                                target="_blank"><i class="bi-door-open-fill me-2"></i> Acessar</a>
                        </div>
                    </div>
                </section>
                <!-- Footer-->
                <footer class="bg-black text-center py-5">
                    <div class="container px-5">
                        <div class="text-white-50 small">
                            <div class="mb-2">&copy; Prefeitura Municipal de Angra dos Reis</div>
                        </div>
                    </div>
                </footer>




            </div>
        </div>
    </section>

    <script src="../assets/dist/js/bootstrap.bundle.min.js"></script>

                <script src="https://plugin.handtalk.me/web/latest/handtalk.min.js"></script>
                <script>
                    var ht = new HT({
                        token: "7a92081e27daf17bd3b2efe277d0648c",
                        avatar: "MAYA",
                        pageSpeech: true,
                        maxTextSize: 1000
                    });
                </script>

                <script>
                    function mostrarRestante() {
                        var restantePerguntas = document.getElementById("restantePerguntas");
                        var buttonPERG = document.querySelector("#buttonFAQ");
                        var mostrar = "Mostrar Mais Perguntas";
                        var ocultar = " - Ocultar Perguntas";

                        if (restantePerguntas.style.display === "none") {
                            restantePerguntas.style.display = "block";
                            buttonPERG.textContent = ocultar;
                            console.log("ocultou");
                        } else {
                            console.log("mostrou");
                            restantePerguntas.style.display = "none";
                            buttonPERG.textContent = mostrar;
                        }
                    }
                </script>
@endsection